"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.destination = void 0;
const tslib_1 = require("tslib");
const shim_1 = require("@segment/browser-destination-runtime/shim");
const actions_core_1 = require("@segment/actions-core");
const trackEvent_1 = tslib_1.__importDefault(require("./trackEvent"));
const identifyUser_1 = tslib_1.__importDefault(require("./identifyUser"));
const identifyGroup_1 = tslib_1.__importDefault(require("./identifyGroup"));
exports.destination = {
    name: 'Survicate (Actions)',
    slug: 'actions-survicate',
    mode: 'device',
    description: 'Send user traits to Survicate and trigger surveys with Segment events',
    presets: [
        {
            name: 'Track Event',
            subscribe: 'type = "track"',
            partnerAction: 'trackEvent',
            mapping: actions_core_1.defaultValues(trackEvent_1.default.fields),
            type: 'automatic'
        },
        {
            name: 'Identify User',
            subscribe: 'type = "identify"',
            partnerAction: 'identifyUser',
            mapping: actions_core_1.defaultValues(identifyUser_1.default.fields),
            type: 'automatic'
        },
        {
            name: 'Identify Group',
            subscribe: 'type = "group"',
            partnerAction: 'identifyGroup',
            mapping: actions_core_1.defaultValues(identifyGroup_1.default.fields),
            type: 'automatic'
        }
    ],
    settings: {
        workspaceKey: {
            description: 'The workspace key for your Survicate account.',
            label: 'Workspace Key',
            type: 'string',
            required: true
        }
    },
    initialize: async ({ settings }, deps) => {
        try {
            await deps.loadScript(`https://survey.survicate.com/workspaces/${settings.workspaceKey}/web_surveys.js`);
            await deps.resolveWhen(() => window._sva != undefined, 100);
            return window._sva;
        }
        catch (error) {
            throw new Error('Failed to load Survicate. ' + error);
        }
    },
    actions: {
        trackEvent: trackEvent_1.default,
        identifyUser: identifyUser_1.default,
        identifyGroup: identifyGroup_1.default
    }
};
exports.default = shim_1.browserDestination(exports.destination);
//# sourceMappingURL=index.js.map